@@ -82,7 +82,7 @@ class Recipe(object):
         s = f.read()
         f.close()
         r = re.search(r'http://production.cf.rubygems.org/rubygems/'
-                      r'rubygems-([0-9.]+).tgz', s)
+                      r'rubygems-([0-9.]+).zip', s)
         if r:
             url = r.group(0)
             version = r.group(1)
